@@ -27,7 +27,7 @@ my $i=1;
 my @ips = ("209.73.229.163","200.52.173.3","211.184.167.213","80.105.135.82","196.218.159.212");
 my $ok = 1;
 foreach my $ip (@ips) {
-        my $response = whoisip_query($ip);
+        my $response = whoisip_query($ip,ARIN);
         if(ref($response) ne "HASH") {
 		$ok=0;
                 print "not ";
